#
# Copyright (C) 2009-2012 Alexis Bienvenue <paamc@passoire.fr>
#
# This file is part of Auto-Multiple-Choice
#
# Auto-Multiple-Choice is free software: you can redistribute it
# and/or modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, either version 2 of
# the License, or (at your option) any later version.
#
# Auto-Multiple-Choice is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Auto-Multiple-Choice.  If not, see
# <http://www.gnu.org/licenses/>.

package AMC::Export::rawcsv;

use AMC::Basic;
use AMC::Export;

use Encode;

@ISA=("AMC::Export");

sub new {
    my $class = shift;
    my $self  = $class->SUPER::new();
    $self->{'out.columns'}='student.copy,student.key,student.name';
    bless ($self, $class);
    return $self;
}

sub load {
  my ($self)=@_;
  $self->SUPER::load();
  $self->{'_capture'}=$self->{'_data'}->module('capture');
}

sub parse_num {
    my ($self,$n)=@_;
    return($n);
}

sub parse_string {
    my ($self,$s)=@_;
    if($self->{'out.entoure'}) {
	$s =~ s/"/""/g;
	$s='"'.$s.'"';
    }
    return($s);
}

sub export {
    my ($self,$fichier)=@_;
    my $sep=',';

    $self->pre_process();

    open(OUT,">:encoding(utf-8)",$fichier);

    $self->{'_scoring'}->{'statements'}->{'allAnswers'}=
      {'sql'=>"SELECT answer FROM scoring.scoring_answer WHERE question=? GROUP BY answer ORDER BY answer"}
      if(!$self->{'_scoring'}->{'statements'}->{'allAnswers'});

    $self->{'_scoring'}->begin_read_transaction('XCSV');

    my $dt=$self->{'_scoring'}->variable('darkness_threshold');
    my $lk=$self->{'_assoc'}->variable('key_in_list');

    my @student_columns=split(/,+/,$self->{'out.columns'});

    my @columns=();

    for my $c (@student_columns) {
      if($c eq 'student.key') {
	push @columns,"A:".encode('utf-8',$lk);
      } elsif($c eq 'student.name') {
	push @columns,translate_column_title('nom');
      } elsif($c eq 'student.copy') {
	push @columns,translate_column_title('copie');
      } else {
	push @columns,encode('utf-8',$c);
      }
    }

    my @questions=$self->{'_scoring'}->questions;

    my %qa=();

    for my $q (@questions) {
      my @a=$self->{'_scoring'}->sql_list($self->{'_scoring'}->statement('allAnswers'),$q->{'question'});
      for (@a) {
	push @columns,$q->{'title'}.":".$_;
      }
    }

    push @columns;

    print OUT join($sep,map  { $self->parse_string($_) } @columns)."\n";

    for my $m (@{$self->{'marks'}}) {
      my @sc=($m->{'student'},$m->{'copy'});

      @columns=();

      for my $c (@student_columns) {
	push @columns,$self->parse_string($m->{$c} ?
					  $m->{$c} :
					  $m->{'student.all'}->{$c});
      }

      for my $q (@questions) {
	push @columns,$self->{'_capture'}
	  ->ticked_list(@sc,$q->{'question'},$dt);
      }

      print OUT join($sep,@columns)."\n";
    }

    close(OUT);
}

1;
